iu_client: ranap_iu_tx_release() change default cause code to Success

The cause code no remaining rab should be only used when closing the
Iu connection on this specific reason. Change default to NAS Success
Release which is a usual release.

Change-Id: Icf3f06b0de7dcda9f967ae29863054ef813c75e5
diff --git a/src/iu_client.c b/src/iu_client.c
index f4a9cd3..4b0acb0 100644
--- a/src/iu_client.c
+++ b/src/iu_client.c
@@ -468,15 +468,15 @@
 }
 
 /* Send Iu Release for the given UE connection.
  * If cause is NULL, the standard "No remaining RAB" cause is sent, otherwise
  * the provided cause. */
 int ranap_iu_tx_release(struct ranap_ue_conn_ctx *ctx, const struct RANAP_Cause *cause)
 {
 	struct msgb *msg;
 	struct osmo_scu_prim *prim;
 	static const struct RANAP_Cause default_cause = {
-		.present = RANAP_Cause_PR_radioNetwork,
-		.choice.radioNetwork = RANAP_CauseRadioNetwork_no_remaining_rab,
+		.present = RANAP_Cause_PR_nAS,
+		.choice.radioNetwork = RANAP_CauseNAS_normal_release,
 	};
 
 	if (!cause)
@@ -468,15 +468,15 @@
 
 /* Send Iu Release for the given UE connection.
- * If cause is NULL, the standard "No remaining RAB" cause is sent, otherwise
+ * If cause is NULL, Normal Release cause is sent, otherwise
  * the provided cause. */
 int ranap_iu_tx_release(struct ranap_ue_conn_ctx *ctx, const struct RANAP_Cause *cause)